# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/sindr',
                'doc_host': 'https://$GIT_USER_NAME.github.io',
                'git_url': 'https://github.com/$GIT_USER_NAME/sindr',
                'lib_path': 'sindr'},
  'syms': { 'sindr.core': { 'sindr.core.get_config': ('core.html#get_config', 'sindr/core.py'),
                            'sindr.core.get_samplesheet': ('core.html#get_samplesheet', 'sindr/core.py'),
                            'sindr.core.set_env_variables': ('core.html#set_env_variables', 'sindr/core.py'),
                            'sindr.core.show_project_env_vars': ('core.html#show_project_env_vars', 'sindr/core.py')},
            'sindr.hello_world': { 'sindr.hello_world.cli': ('hello_world.html#cli', 'sindr/hello_world.py'),
                                   'sindr.hello_world.hello_world': ('hello_world.html#hello_world', 'sindr/hello_world.py')},
            'sindr.seq_tools': { 'sindr.seq_tools.DnaSeq': ('seq_tools.html#dnaseq', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.__add__': ('seq_tools.html#dnaseq.__add__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.__init__': ('seq_tools.html#dnaseq.__init__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.__iter__': ('seq_tools.html#dnaseq.__iter__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.__len__': ('seq_tools.html#dnaseq.__len__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.__repr__': ('seq_tools.html#dnaseq.__repr__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.from_fasta': ('seq_tools.html#dnaseq.from_fasta', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.iupac_counts': ('seq_tools.html#dnaseq.iupac_counts', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.phred_score_to_int': ( 'seq_tools.html#dnaseq.phred_score_to_int',
                                                                                'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.print_fasta': ('seq_tools.html#dnaseq.print_fasta', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.reverse_complement': ( 'seq_tools.html#dnaseq.reverse_complement',
                                                                                'sindr/seq_tools.py'),
                                 'sindr.seq_tools.DnaSeq.translate': ('seq_tools.html#dnaseq.translate', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta': ('seq_tools.html#fasta', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.__init__': ('seq_tools.html#fasta.__init__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.__iter__': ('seq_tools.html#fasta.__iter__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.__len__': ('seq_tools.html#fasta.__len__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.__repr__': ('seq_tools.html#fasta.__repr__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.concat_seq': ('seq_tools.html#fasta.concat_seq', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.from_file': ('seq_tools.html#fasta.from_file', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.iupac_counts': ('seq_tools.html#fasta.iupac_counts', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fasta.write': ('seq_tools.html#fasta.write', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fastq': ('seq_tools.html#fastq', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fastq.__init__': ('seq_tools.html#fastq.__init__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fastq.__iter__': ('seq_tools.html#fastq.__iter__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fastq.__len__': ('seq_tools.html#fastq.__len__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fastq.__repr__': ('seq_tools.html#fastq.__repr__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fastq.from_file': ('seq_tools.html#fastq.from_file', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.Fastq.write': ('seq_tools.html#fastq.write', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.NcbiDataSummarizer': ('seq_tools.html#ncbidatasummarizer', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.NcbiDataSummarizer.get_files': ( 'seq_tools.html#ncbidatasummarizer.get_files',
                                                                                   'sindr/seq_tools.py'),
                                 'sindr.seq_tools.NcbiDataSummarizer.summarize_genomic_fna': ( 'seq_tools.html#ncbidatasummarizer.summarize_genomic_fna',
                                                                                               'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinFasta': ('seq_tools.html#proteinfasta', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinFasta.__init__': ('seq_tools.html#proteinfasta.__init__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinFasta.from_file': ('seq_tools.html#proteinfasta.from_file', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq': ('seq_tools.html#proteinseq', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq.__add__': ('seq_tools.html#proteinseq.__add__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq.__init__': ('seq_tools.html#proteinseq.__init__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq.__iter__': ('seq_tools.html#proteinseq.__iter__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq.__len__': ('seq_tools.html#proteinseq.__len__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq.__repr__': ('seq_tools.html#proteinseq.__repr__', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq.from_fasta': ('seq_tools.html#proteinseq.from_fasta', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.ProteinSeq.print_fasta': ('seq_tools.html#proteinseq.print_fasta', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.SpadesAssembly': ('seq_tools.html#spadesassembly', 'sindr/seq_tools.py'),
                                 'sindr.seq_tools.SpadesAssembly.contig_stats': ( 'seq_tools.html#spadesassembly.contig_stats',
                                                                                  'sindr/seq_tools.py'),
                                 'sindr.seq_tools.SpadesAssembly.filter_contigs': ( 'seq_tools.html#spadesassembly.filter_contigs',
                                                                                    'sindr/seq_tools.py')},
            'sindr.some_string': {}}}
